@@ -1,17 +1,17 @@
 /*
  *
- *  This file is part of MUMPS 4.8.4, built on Mon Dec 15 15:31:38 UTC 2008
+ *  This file is part of MUMPS 4.9.2, built on Thu Nov  5 07:05:08 UTC 2009
  *
  *
  *  This version of MUMPS is provided to you free of charge. It is public
  *  domain, based on public domain software developed during the Esprit IV
  *  European project PARASOL (1996-1999) by CERFACS, ENSEEIHT-IRIT and RAL.
  *  Since this first public domain version in 1999, the developments are
- *  supported by the following institutions: CERFACS, ENSEEIHT-IRIT, and
- *  INRIA.
+ *  supported by the following institutions: CERFACS, CNRS, INPT(ENSEEIHT)-
+ *  IRIT, and INRIA.
  *
- *  Main contributors are Patrick Amestoy, Iain Duff, Abdou Guermouche,
- *  Jacko Koster, Jean-Yves L'Excellent, and Stephane Pralet.
+ *  Current development team includes Patrick Amestoy, Alfredo Buttari,
+ *  Abdou Guermouche, Jean-Yves L'Excellent, Bora Ucar.
  *
  *  Up-to-date copies of the MUMPS package can be obtained
  *  from the Web pages:
@@ -24,21 +24,17 @@
  *
  *  User documentation of any code that uses this software can
  *  include this complete notice. You can acknowledge (using
- *  references [1], [2], and [3]) the contribution of this package
+ *  references [1] and [2]) the contribution of this package
  *  in any scientific publication dependent upon the use of the
  *  package. You shall use reasonable endeavours to notify
  *  the authors of the package of this publication.
  *
- *   [1] P. R. Amestoy, I. S. Duff and  J.-Y. L'Excellent,
- *   Multifrontal parallel distributed symmetric and unsymmetric solvers,
- *   in Comput. Methods in Appl. Mech. Eng., 184,  501-520 (2000).
- *
- *   [2] P. R. Amestoy, I. S. Duff, J. Koster and  J.-Y. L'Excellent,
+ *   [1] P. R. Amestoy, I. S. Duff, J. Koster and  J.-Y. L'Excellent,
  *   A fully asynchronous multifrontal solver using distributed dynamic
  *   scheduling, SIAM Journal of Matrix Analysis and Applications,
  *   Vol 23, No 1, pp 15-41 (2001).
  *
- *   [3] P. R. Amestoy and A. Guermouche and J.-Y. L'Excellent and
+ *   [2] P. R. Amestoy and A. Guermouche and J.-Y. L'Excellent and
  *   S. Pralet, Hybrid scheduling for the parallel solution of linear
  *   systems. Parallel Computing Vol 32 (2), pp 136-156 (2006).
  *
@@ -102,7 +98,7 @@ void*  mumps_async_thread_function_with_sem (void* arg){
 	{
 	 case IO_WRITE:
 	   ret_code=mumps_io_do_write_block(current_io_request->addr,
-				     &(current_io_request->size),
+				     current_io_request->size,
                                      &(current_io_request->file_type),
 				     current_io_request->vaddr,
 				     &ierr);
@@ -112,7 +108,7 @@ void*  mumps_async_thread_function_with_sem (void* arg){
 	   break;
 	case IO_READ:
 	  ret_code=mumps_io_do_read_block(current_io_request->addr,
-				   &(current_io_request->size),
+				   current_io_request->size,
                                    &(current_io_request->file_type),
               			   current_io_request->vaddr,
 				   &ierr);
@@ -389,7 +385,7 @@ int mumps_low_level_init_ooc_c_th(int* async, int* ierr){
 }
 int mumps_async_write_th(const int * strat_IO, 
 			void * address_block,
-			int * block_size,
+                        long long block_size,
 			int * inode,
 			int * request_arg,
 		        int * type,
@@ -420,7 +416,7 @@ int mumps_async_write_th(const int * strat_IO,
     io_queue[cur_req].inode=*inode; 
     io_queue[cur_req].req_num=current_req_num; 
     io_queue[cur_req].addr=address_block; 
-    io_queue[cur_req].size=*block_size;  
+    io_queue[cur_req].size=block_size;  
     io_queue[cur_req].vaddr=vaddr;
     io_queue[cur_req].io_type=0;
     io_queue[cur_req].file_type=*type;
@@ -445,7 +441,7 @@ int mumps_async_write_th(const int * strat_IO,
 }
 int mumps_async_read_th(const int * strat_IO, 
 		       void * address_block,
-		       int * block_size,
+		       long long  block_size,
 		       int * inode,
 		       int * request_arg,
          	       int * type,
@@ -483,7 +479,7 @@ int mumps_async_read_th(const int * strat_IO,
     io_queue[cur_req].inode=*inode;
     io_queue[cur_req].req_num=current_req_num; 
     io_queue[cur_req].addr=address_block; 
-    io_queue[cur_req].size=*block_size;  
+    io_queue[cur_req].size=block_size;  
     io_queue[cur_req].vaddr=vaddr;
     io_queue[cur_req].io_type=1;
     io_queue[cur_req].file_type=*type;
